package ch.zhaw.pm2.multichat.client;

import javafx.application.Application;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.layout.Pane;
import javafx.stage.Stage;

/**
 * Class in charge of initializing and loading elements needed for the GUI.
 * Also Launching the chat window with pre-given parameters
 */
public class ClientUI extends Application {
    private final ClientMessageList clientMessageList = new ClientMessageList();
    private final ClientConnectionHandler connectionHandler = new ClientConnectionHandler(clientMessageList);

    /**
     * Start method will only run the chatWindow method.
     *
     * @param primaryStage the primary stage for this application, onto which
     *                     the application scene can be set.
     *                     Applications may create other stages, if needed, but they will not be
     *                     primary stages.
     */
    @Override
    public void start(Stage primaryStage) {
        chatWindow(primaryStage);
    }

    /**
     * Method is in charge of loading the FXML file and then initializing the controllers and setting some parameters for the stage.
     *
     * @param primaryStage of the Application onto which the Scene is set.
     */
    private void chatWindow(Stage primaryStage) {
        try {
            FXMLLoader loader = new FXMLLoader(getClass().getResource("ChatWindow.fxml"));
            Pane rootPane = loader.load();

            ChatWindowController chatWindowController = loader.getController();
            chatWindowController.setMessages(clientMessageList);
            chatWindowController.setConnectionHandler(connectionHandler);

            // fill in scene and stage setup
            Scene scene = new Scene(rootPane);
            //scene.getStylesheets().add(getClass().getResource("application.css").toExternalForm());

            // configure and show stage
            primaryStage.setScene(scene);
            primaryStage.setMinHeight(250);
            primaryStage.setTitle("Multichat Client");
            primaryStage.show();
            primaryStage.setMinWidth(primaryStage.getWidth()); //use automatically computed size as Minimum Size.
        } catch (Exception e) {
            System.err.println("Error starting up UI" + e.getMessage());
        }
    }
}
