package ch.zhaw.pm2.multichat.protocol;

import java.io.Serializable;

/**
 * A Message object represents one Message of a client. Can be stored in ClientMessageList.
 */
public class Message implements Serializable {
    private final ConnectionHandler.DATA_TYPE type;
    private String sender;
    private final String receiver;
    private final String text;

    /**
     * Constructor of Message. Needs all Information about a Message to save them.
     *
     * @param type     Message (if it's a message typed by a user), Error or Information (if it is generated automatically, in this case sender and receiver will be null)
     * @param sender   The User who has sent the message.
     * @param receiver The User who should receive the message.
     * @param text     The Text of the message.
     */
    public Message(ConnectionHandler.DATA_TYPE type, String sender, String receiver, String text) {
        this.type = type;
        this.sender = sender;
        this.receiver = receiver;
        this.text = text;
    }

    /**
     * Checks if the Filter String is contained in one of the data fields sender, receiver or text
     *
     * @param filter The Filter String
     * @return true if it is the Filter String is contained in a data field.
     */
    public boolean matchesFilter(String filter) {
        return (sender != null && sender.contains(filter)) ||
                (receiver != null && receiver.contains(filter)) ||
                (text != null && text.contains(filter));
    }

    /**
     * @return The type of the message.
     */
    public ConnectionHandler.DATA_TYPE getType() {
        return type;
    }

    /**
     * @return The User who has sent the Message.
     */
    public String getSender() {
        return sender;
    }

    /**
     * @return The Receiver who receives the Message.
     */
    public String getReceiver() {
        return receiver;
    }

    /**
     * @return The Text of the Message.
     */
    public String getText() {
        return text;
    }

    public void setSender(String sender) {
        this.sender = sender;
    }
}
